External Data Providers
.......................

:mod:`hgvs.dataproviders.interface`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.dataproviders.interface

:mod:`hgvs.dataproviders.multifastadb`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.dataproviders.multifastadb

:mod:`hgvs.dataproviders.uta`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.dataproviders.uta
